@@ -1,3 +1,5 @@
+from collections import defaultdict
+from datetime import datetime
 import logging
 from typing import Dict, Optional, List
 
@@ -13,6 +15,20 @@ from dynatrace.http_client import HttpClient
 from dynatrace.metric import MetricSeriesCollection, MetricDescriptor
 from dynatrace.pagination import PaginatedList
 from dynatrace.plugins import PluginShortRepresentation, PluginState
+from dynatrace.synthetic_third_party import (
+    ThirdPartySyntheticTests,
+    ThirdPartySyntheticLocation,
+    ThirdPartySyntheticMonitor,
+    SyntheticTestLocation,
+    ThirdPartySyntheticResult,
+    ThirdPartySyntheticLocationTestResult,
+    SyntheticMonitorStepResult,
+    SyntheticMonitorError,
+    SyntheticTestStep,
+    ThirdPartyEventResolvedNotification,
+    ThirdPartyEventOpenNotification,
+    ThirdPartySyntheticEvents,
+)
 
 
 class Dynatrace:
@@ -20,6 +36,7 @@ class Dynatrace:
         self, base_url: str, token: str, log: logging.Logger = None, proxies: Dict = None, too_many_requests_strategy=None
     ):
         self.__http_client = HttpClient(base_url, token, log, proxies, too_many_requests_strategy)
+        self.__open_third_party_events: Dict[str, int] = defaultdict(int)
 
     def get_entities(
         self, entity_selector: str, time_from: str = "now-2h", time_to: str = "now", fields: Optional[str] = None, page_size=50
@@ -448,3 +465,67 @@ class Dynatrace:
         return ExtensionConfigurationDto(
             self.__http_client, extension_id, enabled, use_global, properties, host_id, active_gate, endpoint_id, endpoint_name
         )
+
+    def report_simple_thirdparty_synthetic_test(
+        self,
+        engine_name: str,
+        timestamp: datetime,
+        location_id: str,
+        location_name: str,
+        test_id: str,
+        test_title: str,
+        step_title: str,
+        schedule_interval: int,
+        success: bool,
+        response_time: int,
+        icon_url: str = None,
+        edit_link: str = None,
+    ):
+
+        location = ThirdPartySyntheticLocation(self.__http_client, location_id, location_name)
+        synthetic_location = SyntheticTestLocation(self.__http_client, location_id)
+        step = SyntheticTestStep(self.__http_client, 1, step_title)
+        monitor = ThirdPartySyntheticMonitor(
+            self.__http_client, test_id, test_title, [synthetic_location], schedule_interval, steps=[step], edit_link=edit_link
+        )
+        step_result = SyntheticMonitorStepResult(self.__http_client, 1, timestamp, response_time_millis=response_time)
+        location_result = ThirdPartySyntheticLocationTestResult(
+            self.__http_client, location_id, timestamp, success, step_results=[step_result]
+        )
+        test_result = ThirdPartySyntheticResult(self.__http_client, test_id, 1, [location_result])
+        tests = ThirdPartySyntheticTests(
+            self.__http_client, engine_name, timestamp, [location], [monitor], [test_result], synthetic_engine_icon_url=icon_url
+        )
+        return tests.post()
+
+    def report_simple_thirdparty_synthetic_test_event(
+        self,
+        test_id: str,
+        name: str,
+        location_id: str,
+        timestamp: datetime,
+        state: str,
+        event_type: str,
+        reason: str,
+        engine_name: str,
+    ):
+        opened_events: List[ThirdPartyEventOpenNotification] = []
+        resolved_events = []
+        if state == "open":
+            self.__open_third_party_events[test_id] += 1
+            event_id = f"{test_id}_{self.__open_third_party_events[test_id]}"
+
+            opened_events.append(
+                ThirdPartyEventOpenNotification(
+                    self.__http_client, test_id, event_id, name, event_type, reason, timestamp, [location_id]
+                )
+            )
+        else:
+            if test_id in self.__open_third_party_events:
+                event_ids = [f"{test_id}_{i + 1}" for i in range(self.__open_third_party_events[test_id])]
+                for event_id in event_ids:
+                    resolved_events.append(ThirdPartyEventResolvedNotification(self.__http_client, test_id, event_id, timestamp))
+                del self.__open_third_party_events[test_id]
+
+        events = ThirdPartySyntheticEvents(self.__http_client, engine_name, opened_events, resolved_events)
+        return events.post()
